@@ -173,6 +173,8 @@ fn prebuilt_url(tool: &Tool, version: &str) -> Result<String> {
 /// Get the download URL for some tool at some version, architecture and operating system
 pub fn prebuilt_url_for(tool: &Tool, version: &str, arch: &Arch, os: &Os) -> Result<String> {
     let target = match (os, arch, tool) {
+        (Os::Linux, Arch::AArch64, Tool::WasmOpt) => "aarch64-linux",
+        (Os::Linux, Arch::AArch64, _) => "aarch64-unknown-linux-gnu",
         (Os::Linux, Arch::X86_64, Tool::WasmOpt) => "x86_64-linux",
         (Os::Linux, Arch::X86_64, _) => "x86_64-unknown-linux-musl",
         (Os::MacOS, Arch::X86_64, Tool::WasmOpt) => "x86_64-macos",
@@ -194,14 +196,14 @@ pub fn prebuilt_url_for(tool: &Tool, version: &str, arch: &Arch, os: &Os) -> Res
         Tool::CargoGenerate => {
             Ok(format!(
                 "https://github.com/cargo-generate/cargo-generate/releases/download/v{0}/cargo-generate-v{0}-{1}.tar.gz",
-                "0.17.3",
+                "0.18.2",
                 target
             ))
         },
         Tool::WasmOpt => {
             Ok(format!(
         "https://github.com/WebAssembly/binaryen/releases/download/{vers}/binaryen-{vers}-{target}.tar.gz",
-        vers = "version_111",
+        vers = "version_117",
         target = target,
             ))
         }
