@@ -20,7 +20,6 @@ use crate::PBAR;
 use cargo_metadata::Metadata;
 use chrono::offset;
 use chrono::DateTime;
-use curl::easy;
 use serde::{self, Deserialize};
 use serde_json;
 use std::collections::BTreeSet;
@@ -118,15 +117,9 @@ struct CargoWasmPackProfileWasmBindgen {
 
     #[serde(default, rename = "dwarf-debug-info")]
     dwarf_debug_info: Option<bool>,
-}
 
-struct Collector(Vec<u8>);
-
-impl easy::Handler for Collector {
-    fn write(&mut self, data: &[u8]) -> Result<usize, easy::WriteError> {
-        self.0.extend_from_slice(data);
-        Ok(data.len())
-    }
+    #[serde(default, rename = "omit-default-module-path")]
+    omit_default_module_path: Option<bool>,
 }
 
 /// Struct for storing information received from crates.io
@@ -233,26 +226,24 @@ impl Crate {
     /// Call to the crates.io api and return the latest version of `wasm-pack`
     fn check_wasm_pack_latest_version() -> Result<Crate> {
         let url = "https://crates.io/api/v1/crates/wasm-pack";
+        let agent = ureq::builder()
+            .user_agent(&format!(
+                "wasm-pack/{} ({})",
+                WASM_PACK_VERSION.unwrap_or_else(|| "unknown"),
+                WASM_PACK_REPO_URL
+            ))
+            .build();
+        let resp = agent
+            .get(url)
+            .call()
+            .context("failed to get wasm-pack version")?;
 
-        let mut easy = easy::Easy2::new(Collector(Vec::new()));
-
-        easy.useragent(&format!(
-            "wasm-pack/{} ({})",
-            WASM_PACK_VERSION.unwrap_or_else(|| "unknown"),
-            WASM_PACK_REPO_URL
-        ))?;
-
-        easy.url(url)?;
-        easy.get(true)?;
-        easy.perform()?;
-
-        let status_code = easy.response_code()?;
+        let status_code = resp.status();
 
         if 200 <= status_code && status_code < 300 {
-            let contents = easy.get_ref();
-            let result = String::from_utf8_lossy(&contents.0);
+            let json = resp.into_json()?;
 
-            Ok(serde_json::from_str(result.into_owned().as_str())?)
+            Ok(json)
         } else {
             bail!(
                 "Received a bad HTTP status code ({}) when checking for newer wasm-pack version at: {}",
@@ -283,6 +274,7 @@ impl CargoWasmPackProfile {
                 debug_js_glue: Some(true),
                 demangle_name_section: Some(true),
                 dwarf_debug_info: Some(false),
+                omit_default_module_path: Some(false),
             },
             wasm_opt: None,
         }
@@ -294,6 +286,7 @@ impl CargoWasmPackProfile {
                 debug_js_glue: Some(false),
                 demangle_name_section: Some(true),
                 dwarf_debug_info: Some(false),
+                omit_default_module_path: Some(false),
             },
             wasm_opt: Some(CargoWasmPackProfileWasmOpt::Enabled(true)),
         }
@@ -305,6 +298,7 @@ impl CargoWasmPackProfile {
                 debug_js_glue: Some(false),
                 demangle_name_section: Some(true),
                 dwarf_debug_info: Some(false),
+                omit_default_module_path: Some(false),
             },
             wasm_opt: Some(CargoWasmPackProfileWasmOpt::Enabled(true)),
         }
@@ -346,6 +340,7 @@ impl CargoWasmPackProfile {
         d!(wasm_bindgen.debug_js_glue);
         d!(wasm_bindgen.demangle_name_section);
         d!(wasm_bindgen.dwarf_debug_info);
+        d!(wasm_bindgen.omit_default_module_path);
 
         if self.wasm_opt.is_none() {
             self.wasm_opt = defaults.wasm_opt.clone();
@@ -367,6 +362,11 @@ impl CargoWasmPackProfile {
         self.wasm_bindgen.dwarf_debug_info.unwrap()
     }
 
+    /// Get this profile's configured `[wasm-bindgen.omit-default-module-path]` value.
+    pub fn wasm_bindgen_omit_default_module_path(&self) -> bool {
+        self.wasm_bindgen.omit_default_module_path.unwrap()
+    }
+
     /// Get this profile's configured arguments for `wasm-opt`, if enabled.
     pub fn wasm_opt_args(&self) -> Option<Vec<String>> {
         match self.wasm_opt.as_ref()? {
@@ -449,7 +449,7 @@ impl CrateData {
     pub fn parse_crate_data(manifest_path: &Path) -> Result<ManifestAndUnsedKeys> {
         let manifest = fs::read_to_string(&manifest_path)
             .with_context(|| anyhow!("failed to read: {}", manifest_path.display()))?;
-        let manifest = &mut toml::Deserializer::new(&manifest);
+        let manifest = toml::Deserializer::new(&manifest);
 
         let mut unused_keys = BTreeSet::new();
         let levenshtein_threshold = 1;
@@ -541,6 +541,14 @@ impl CrateData {
         }
     }
 
+    /// Gets the optional path to the readme, or None if disabled.
+    pub fn crate_readme(&self) -> Option<String> {
+        self.pkg()
+            .readme
+            .clone()
+            .map(|readme_file| readme_file.into_string())
+    }
+
     /// Get the license for the crate at the given path.
     pub fn crate_license(&self) -> &Option<String> {
         &self.pkg().license
@@ -714,6 +722,7 @@ impl CrateData {
 
         NpmPackage::ESModulesPackage(ESModulesPackage {
             name: data.name,
+            ty: "module".into(),
             collaborators: pkg.authors.clone(),
             description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
@@ -723,7 +732,7 @@ impl CrateData {
                 url: repo_url,
             }),
             files: data.files,
-            module: data.main.clone(),
+            main: data.main.clone(),
             homepage: data.homepage,
             types: data.dts_file,
             side_effects: vec![format!("./{}", data.main), "./snippets/*".to_owned()],
@@ -746,6 +755,7 @@ impl CrateData {
 
         NpmPackage::ESModulesPackage(ESModulesPackage {
             name: data.name,
+            ty: "module".into(),
             collaborators: pkg.authors.clone(),
             description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
@@ -755,7 +765,7 @@ impl CrateData {
                 url: repo_url,
             }),
             files: data.files,
-            module: data.main,
+            main: data.main,
             homepage: data.homepage,
             types: data.dts_file,
             side_effects: vec!["./snippets/*".to_owned()],
