@@ -1,10 +1,12 @@
 use std::collections::HashMap;
 
-use manifest::npm::repository::Repository;
+use crate::manifest::npm::repository::Repository;
 
 #[derive(Serialize)]
 pub struct ESModulesPackage {
     pub name: String,
+    #[serde(rename = "type")]
+    pub ty: String,
     #[serde(skip_serializing_if = "Vec::is_empty")]
     pub collaborators: Vec<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -16,13 +18,13 @@ pub struct ESModulesPackage {
     pub repository: Option<Repository>,
     #[serde(skip_serializing_if = "Vec::is_empty")]
     pub files: Vec<String>,
-    pub module: String,
+    pub main: String,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub homepage: Option<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub types: Option<String>,
     #[serde(rename = "sideEffects")]
-    pub side_effects: bool,
+    pub side_effects: Vec<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub keywords: Option<Vec<String>>,
     #[serde(skip_serializing_if = "Option::is_none")]
